@@ -11,7 +11,6 @@
 #include "todoviewview.h"
 
 #include <Akonadi/TagSelectionComboBox>
-#include <CalendarSupport/CategoryConfig>
 #include <CalendarSupport/CategoryHierarchyReader>
 
 #include <KCalendarCore/CalFilter>
@@ -82,6 +81,7 @@ void TodoCompleteDelegate::initStyleOptionProgressBar(QStyleOptionProgressBar *o
     option->text = index.data().toString() + QChar::fromLatin1('%');
     option->textAlignment = Qt::AlignCenter;
     option->textVisible = true;
+    option->state |= QStyle::State_Horizontal;
 }
 
 QWidget *TodoCompleteDelegate::createEditor(QWidget *parent, const QStyleOptionViewItem &option, const QModelIndex &index) const
